<?php
/*
 * Register Theme Customizer
 */
add_action('customize_register', 'cocobasictheme_customize_register');

function cocobasictheme_customize_register($wp_customize) {

    function cocobasic_clean_html($value) {
        $allowed_html_array = ocularus_allowed_html();
        $value = wp_kses($value, $allowed_html_array);
        return $value;
    }

    class CocoBasic_Customize_Textarea_Control extends WP_Customize_Control {

        public $type = 'textarea';

        public function render_content() {
            ?>
            <label>
                <span class="customize-control-title"><?php echo esc_html($this->label); ?></span>
                <textarea rows="5" style="width:100%;" <?php $this->link(); ?>><?php echo esc_textarea($this->value()); ?></textarea>
            </label>
            <?php
        }

    }

    //------------------------- WELCOME TEXT SECTION ---------------------------------------------

    $wp_customize->add_section('cocobasic_welocme_text', array(
        'title' => esc_html__('Welcome Text & Search', 'ocularus-wp'),
        'priority' => 30
    ));


    $wp_customize->add_setting('ocularus_site_description', array(
        'default' => '',
        'sanitize_callback' => 'cocobasic_clean_html'
    ));

    $wp_customize->add_control(new CocoBasic_Customize_Textarea_Control($wp_customize, 'ocularus_site_description', array(
        'label' => esc_html__('Welcome Text', 'ocularus-wp'),
        'section' => 'cocobasic_welocme_text',
        'settings' => 'ocularus_site_description'
    )));


    $wp_customize->add_setting('ocularus_show_search', array(
        'default' => 'no',
        'sanitize_callback' => 'cocobasic_clean_html'
    ));

    $wp_customize->add_control('ocularus_show_search', array(
        'label' => esc_html__('Show Search in Menu', 'ocularus-wp'),
        'section' => 'cocobasic_welocme_text',
        'settings' => 'ocularus_show_search',
        'type' => 'radio',
        'choices' => array(
            'yes' => esc_html__('Yes', 'ocularus-wp'),
            'no' => esc_html__('No', 'ocularus-wp'),
    )));

    //------------------------- END MENU TEXT SECTION ---------------------------------------------
    //
    //
    //
    //
    //----------------------------- PORTFOLIO SECTION  ---------------------------------------------
    if (post_type_exists('portfolio')) {
        $wp_customize->add_section('cocobasic_portfolio_section', array(
            'title' => esc_html__('Portfolio settings', 'ocularus-wp'),
            'priority' => 32
        ));

        $wp_customize->add_setting('ocularus_show_nav_portfolio', array(
            'default' => 'no',
            'sanitize_callback' => 'cocobasic_clean_html'
        ));

        $wp_customize->add_control('ocularus_show_nav_portfolio', array(
            'label' => esc_html__('Show Prev/Next on Single Portfolio', 'ocularus-wp'),
            'section' => 'cocobasic_portfolio_section',
            'settings' => 'ocularus_show_nav_portfolio',
            'type' => 'radio',
            'choices' => array(
                'yes' => esc_html__('Yes', 'ocularus-wp'),
                'no' => esc_html__('No', 'ocularus-wp'),
        )));
    }

    //----------------------------- END PORTFOLIO SECTION  ---------------------------------------------
    //
    //
    //----------------------------- IMAGE SECTION  ---------------------------------------------

    $wp_customize->add_section('cocobasic_image_section', array(
        'title' => esc_html__('Images Section', 'ocularus-wp'),
        'priority' => 33
    ));


    $wp_customize->add_setting('ocularus_header_logo', array(
        'default' => get_template_directory_uri() . '/images/logo.png',
        'capability' => 'edit_theme_options',
        'type' => 'option',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control(new WP_Customize_Image_Control($wp_customize, 'ocularus_header_logo', array(
        'label' => esc_html__('Header Logo', 'ocularus-wp'),
        'section' => 'cocobasic_image_section',
        'settings' => 'ocularus_header_logo'
    )));

    $wp_customize->add_setting('ocularus_welcome_background_img', array(
        'default' => '',
        'capability' => 'edit_theme_options',
        'type' => 'option',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control(new WP_Customize_Image_Control($wp_customize, 'ocularus_welcome_background_img', array(
        'label' => esc_html__('Logo Doodle Background Image', 'ocularus-wp'),
        'section' => 'cocobasic_image_section',
        'settings' => 'ocularus_welcome_background_img'
    )));

    $wp_customize->add_setting('ocularus_menu_background_img', array(
        'default' => '',
        'capability' => 'edit_theme_options',
        'type' => 'option',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control(new WP_Customize_Image_Control($wp_customize, 'ocularus_menu_background_img', array(
        'label' => esc_html__('Menu Doodle Background Image', 'ocularus-wp'),
        'section' => 'cocobasic_image_section',
        'settings' => 'ocularus_menu_background_img'
    )));


    //----------------------------- END IMAGE SECTION  ---------------------------------------------
    //
    //
    //
    //----------------------------------COLORS SECTION--------------------

    $wp_customize->add_setting('menu_background_color', array(
        'default' => '#000000',
        'type' => 'option',
        'capability' => 'edit_theme_options',
        'sanitize_callback' => 'sanitize_hex_color'
    ));
    $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'menu_background_color', array(
        'label' => esc_html__('Menu Background Color', 'ocularus-wp'),
        'section' => 'colors',
        'settings' => 'menu_background_color'
    )));


    $wp_customize->add_setting('menu_color', array(
        'default' => '#ffffff',
        'type' => 'option',
        'capability' => 'edit_theme_options',
        'sanitize_callback' => 'sanitize_hex_color'
    ));
    $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'menu_color', array(
        'label' => esc_html__('Menu Item Color', 'ocularus-wp'),
        'section' => 'colors',
        'settings' => 'menu_color'
    )));


    $wp_customize->add_setting('menu_active_color', array(
        'default' => '#8bd2ff',
        'type' => 'option',
        'capability' => 'edit_theme_options',
        'sanitize_callback' => 'sanitize_hex_color'
    ));
    $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'menu_active_color', array(
        'label' => esc_html__('Menu Current Item Color', 'ocularus-wp'),
        'section' => 'colors',
        'settings' => 'menu_active_color'
    )));


    $wp_customize->add_setting('sidebar_text_color', array(
        'default' => '#989898',
        'type' => 'option',
        'capability' => 'edit_theme_options',
        'sanitize_callback' => 'sanitize_hex_color'
    ));
    $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'sidebar_text_color', array(
        'label' => esc_html__('Sidebar Widget Color', 'ocularus-wp'),
        'section' => 'colors',
        'settings' => 'sidebar_text_color'
    )));


    $wp_customize->add_setting('global_select_color', array(
        'default' => '#fef271',
        'type' => 'option',
        'capability' => 'edit_theme_options',
        'sanitize_callback' => 'sanitize_hex_color'
    ));
    $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'global_select_color', array(
        'label' => esc_html__('Select Color', 'ocularus-wp'),
        'section' => 'colors',
        'settings' => 'global_select_color'
    )));


    //----------------------------------------------------------------------------------------------
    //
    //
    //
    //--------------------------------------------------------------------------
    $wp_customize->get_setting('menu_background_color')->transport = 'postMessage';
    $wp_customize->get_setting('menu_color')->transport = 'postMessage';
    $wp_customize->get_setting('menu_active_color')->transport = 'postMessage';
    $wp_customize->get_setting('sidebar_text_color')->transport = 'postMessage';
    $wp_customize->get_setting('global_select_color')->transport = 'postMessage';
    //--------------------------------------------------------------------------
    /*
     * If preview mode is active, hook JavaScript to preview changes
     */
    if ($wp_customize->is_preview() && !is_admin()) {
        add_action('customize_preview_init', 'cocobasictheme_customize_preview_js');
    }
}

/**
 * Bind Theme Customizer JavaScript
 */
function cocobasictheme_customize_preview_js() {
    wp_enqueue_script('cocobasictheme-customizer', get_template_directory_uri() . '/admin/js/custom-admin.js', array('customize-preview'), '20120910', true);
}

/*
 * Generate CSS Styles
 */

class CocoBasicLiveCSS {

    public static function cocobasictheme_customized_style() {
        echo '<style type="text/css">' .
        cocobasic_generate_css('.site-wrapper .menu-left-part', 'background-color', 'menu_background_color') .
        cocobasic_generate_css('.site-wrapper .search-field', 'border-color', 'menu_background_color') .
        cocobasic_generate_css('.site-wrapper .sm-clean a, .site-wrapper .sm-clean a:hover, .site-wrapper .sm-clean a:focus, .site-wrapper .sm-clean a:active, .site-wrapper h4.widgettitle, .site-wrapper .search-field, .site-wrapper #sidebar .footer-social a', 'color', 'menu_color') .
        cocobasic_generate_css('.site-wrapper .search-field:focus', 'border-color', 'menu_color') .
        cocobasic_generate_css('.site-wrapper .search-field::-webkit-input-placeholder', 'color', 'menu_color') .
        cocobasic_generate_css('.site-wrapper .search-field::-moz-placeholder', 'color', 'menu_color') .
        cocobasic_generate_css('.site-wrapper .search-field:-ms-input-placeholder', 'color', 'menu_color') .
        cocobasic_generate_css('.site-wrapper .search-field:-moz-placeholder', 'color', 'menu_color') .
        cocobasic_generate_css('.site-wrapper .sm-clean a:after, .site-wrapper a.read-more:after', 'background-color', 'menu_active_color') .
        cocobasic_generate_css('.site-wrapper .menu-left-part::-webkit-scrollbar-thumb', 'background-color', 'menu_active_color') .
        cocobasic_generate_css('.site-wrapper .sm-clean a span.sub-arrow, .site-wrapper .category-filter-list .button.is-checked, .site-wrapper .category-filter-list .button:hover', 'color', 'menu_active_color') .
        cocobasic_generate_css('.site-wrapper #sidebar, .site-wrapper #sidebar a, .site-wrapper .main-menu.sm-clean .sub-menu li a', 'color', 'sidebar_text_color') .
        cocobasic_generate_css('body .site-wrapper ::selection', 'background-color', 'global_select_color') .
        cocobasic_generate_css('body .site-wrapper ::-moz-selection', 'background-color', 'global_select_color') .
        '</style>';
    }

}

/*
 * Generate CSS Class - Helper Method
 */

function cocobasic_generate_css($selector, $style, $mod_name, $prefix = '', $postfix = '') {
    $return = '';
    $mod = get_option($mod_name);
    if (!empty($mod)) {
        $return = sprintf('%s { %s:%s; }', $selector, $style, $prefix . $mod . $postfix
        );
    }
    return $return;
}
?>