<?php

// <editor-fold defaultstate="collapsed" desc="Setup theme">
if (!function_exists('ocularus_theme_setup')) {

    function ocularus_theme_setup() {

        $lang_dir = get_template_directory() . '/languages';
        load_theme_textdomain('ocularus-wp', $lang_dir);

        global $content_width;
        if (!isset($content_width))
            $content_width = 1140;

		add_theme_support('align-wide');
		
        add_action('wp_enqueue_scripts', 'ocularus_load_scripts_and_style');
        add_action('admin_enqueue_scripts', 'ocularus_my_admin_scripts');
        add_action('admin_print_styles', 'ocularus_options_admin_styles');
        add_filter('excerpt_more', 'ocularus_excerpt_more');
		
        add_theme_support('post-thumbnails', array('post'));
        add_filter('get_search_form', 'ocularus_search_form');
        add_action('widgets_init', 'ocularus_wp_widgets_init');
        add_theme_support('title-tag');

        require get_parent_theme_file_path('/admin/custom-admin.php');

        if (function_exists('automatic-feed-links')) {
            add_theme_support('automatic-feed-links');
        }

        add_action('init', 'ocularus_register_menu');

        add_editor_style('css/custom-editor-style.css');

        if (current_theme_supports('custom-header')) {
            $default_custom_header_settings = array(
                'default-image' => '',
                'random-default' => false,
                'width' => 0,
                'height' => 0,
                'flex-height' => false,
                'flex-width' => false,
                'default-text-color' => '',
                'header-text' => true,
                'uploads' => true,
                'wp-head-callback' => '',
                'admin-head-callback' => '',
                'admin-preview-callback' => '',
            );
            add_theme_support('custom-header', $default_custom_header_settings);
        }

        if (current_theme_supports('custom-background')) {
            $default_custom_background_settings = array(
                'default-color' => '',
                'default-image' => '',
                'wp-head-callback' => '_custom_background_cb',
                'admin-head-callback' => '',
                'admin-preview-callback' => ''
            );
            add_theme_support('custom-background', $default_custom_background_settings);
        }


        /**
         * Include the TGM_Plugin_Activation class.
         */
        require get_parent_theme_file_path('/admin/class-tgm-plugin-activation.php');
        add_action('tgmpa_register', 'ocularus_wp_register_required_plugins');
    }

}

add_action('after_setup_theme', 'ocularus_theme_setup');

//</editor-fold>
// <editor-fold defaultstate="collapsed" desc="Load Google Fonts">
if (!function_exists('ocularus_google_fonts_url')) {

    function ocularus_google_fonts_url() {
        $font_url = '';

        if ('off' !== _x('on', 'Google font: on or off', 'ocularus-wp')) {
            $font_url = add_query_arg('family', urlencode('Montserrat|Roboto:300,300i,400,400i,700,700i'), "//fonts.googleapis.com/css");
        }
        return $font_url;
    }

}
//</editor-fold>
// <editor-fold defaultstate="collapsed" desc="Load CSS and JS">
if (!function_exists('ocularus_load_scripts_and_style')) {

    function ocularus_load_scripts_and_style() {

        wp_enqueue_style('ocularus-google-fonts', ocularus_google_fonts_url(), array(), '1.0.0');


//Initialize once to optimize number of cals to get template directory url method
        $base_theme_url = get_template_directory_uri();

//register and load styles which is used on every pages       
        wp_enqueue_style('ocularus-clear-style', $base_theme_url . '/css/clear.css');
        wp_enqueue_style('ocularus-common-style', $base_theme_url . '/css/common.css');
        wp_enqueue_style('font-awesome', $base_theme_url . '/css/font-awesome.min.css');
        wp_enqueue_style('sm-cleen', $base_theme_url . '/css/sm-clean.css');
        wp_enqueue_style('ocularus-main-theme-style', $base_theme_url . '/style.css');


//JavaScript

        wp_enqueue_script('html5shiv', $base_theme_url . '/js/html5shiv.js');
        wp_script_add_data('html5shiv', 'conditional', 'lt IE 9');
        wp_enqueue_script('respond', $base_theme_url . '/js/respond.min.js');
        wp_script_add_data('respond', 'conditional', 'lt IE 9');
        wp_enqueue_script('jquery-smartmenus', $base_theme_url . '/js/jquery.smartmenus.min.js', array('jquery'), false, true);
        wp_enqueue_script('jquery-fitvids', $base_theme_url . '/js/jquery.fitvids.js', array('jquery'), false, true);
        wp_enqueue_script('ocularus-main', $base_theme_url . '/js/main.js', array('jquery'), false, true);

        if (is_singular()) {
            if (get_option('thread_comments')) {
                wp_enqueue_script('comment-reply');
            }
        }        
		
		$inlineHeaderCss = CocoBasicLiveCSS::cocobasictheme_customized_style();
		if($inlineHeaderCss !== NULL){
			wp_add_inline_style('ocularus-main', $inlineHeaderCss);
		}	
		
    }

}
// </editor-fold>
// <editor-fold defaultstate="collapsed" desc="Admin JS"> 
if (!function_exists('ocularus_my_admin_scripts')) {

    function ocularus_my_admin_scripts() {
        wp_enqueue_script('ocularus-my-admin-js', get_template_directory_uri() . '/admin/js/admin.js', array('jquery'));
    }

}
// </editor-fold>
// <editor-fold defaultstate="collapsed" desc="Admin CSS"> 
if (!function_exists('ocularus_options_admin_styles')) {

    function ocularus_options_admin_styles() {
        wp_enqueue_style('ocularus-wp-custom-admin-layout-css', get_template_directory_uri() . '/admin/css/layout.css');
    }

}

// </editor-fold>
// <editor-fold defaultstate="collapsed" desc="Custom Excerpt"> 
if (!function_exists('ocularus_excerpt_more')) {

    function ocularus_excerpt_more($more) {
        return ' ...';
    }

}

// </editor-fold>
// <editor-fold defaultstate="collapsed" desc="Custom Search form">
if (!function_exists('ocularus_search_form')) {

    function ocularus_search_form($form) {
        $form = '<form role="search" method="get" class="search-form" action="' . esc_url(home_url('/')) . '">
	<label>		
	<input autocomplete="off" type="search" class="search-field" placeholder="' . esc_attr__('Search', 'ocularus-wp') . '" value="" name="s" title="' . esc_attr__('Search for:', 'ocularus-wp') . '" /> 
</label>    
</form>';

        return $form;
    }

}

//</editor-fold>
// <editor-fold defaultstate="collapsed" desc="Register theme menu">
if (!function_exists('ocularus_register_menu')) {

    function ocularus_register_menu() {
        register_nav_menu('custom_menu', 'Main Menu');
    }

}

// </editor-fold>
// <editor-fold defaultstate="collapsed" desc="Custom menu Walker">
if (!class_exists('ocularus_header_menu')) {

    class ocularus_header_menu extends Walker_Nav_Menu {

        var $number = 1;

        function start_el(&$output, $item, $depth = 0, $args = array(), $id = 0) {
            $indent = ( $depth ) ? str_repeat("\t", $depth) : '';

            $class_names = $value = '';

            $classes = empty($item->classes) ? array() : (array) $item->classes;
            $classes[] = 'menu-item-' . $item->ID;

            $class_names = join(' ', apply_filters('nav_menu_css_class', array_filter($classes), $item, $args));
            $class_names = $class_names ? ' class="' . esc_attr($class_names) . '"' : '';

            $id = apply_filters('nav_menu_item_id', 'menu-item-' . $item->ID, $item, $args);
            $id = $id ? ' id="' . esc_attr($id) . '"' : '';

            $output .= $indent . '<li' . $id . $value . $class_names . '>';

            $atts = array();
            $atts['title'] = !empty($item->attr_title) ? $item->attr_title : '';
            $atts['target'] = !empty($item->target) ? $item->target : '';
            $atts['rel'] = !empty($item->xfn) ? $item->xfn : '';
            $atts['href'] = !empty($item->url) ? $item->url : '';

            $atts = apply_filters('nav_menu_link_attributes', $atts, $item, $args);

            $attributes = '';
            foreach ($atts as $attr => $value) {
                if (!empty($value)) {
                    $value = ( 'href' === $attr ) ? esc_url($value) : esc_attr($value);
                    $attributes .= ' ' . $attr . '="' . $value . '"';
                }
            }

            $item_output = $args->before;
            $item_output .= '<a' . $attributes . '>';
            $item_output .= $args->link_before . apply_filters('the_title', $item->title, $item->ID) . $args->link_after;
            $item_output .= '</a>';
            $item_output .= $args->after;

            $output .= apply_filters('walker_nav_menu_start_el', $item_output, $item, $depth, $args);
        }

    }

}

//</editor-fold>
// <editor-fold defaultstate="collapsed" desc="TGM Plugin">
if (!function_exists('ocularus_wp_register_required_plugins')) {

    function ocularus_wp_register_required_plugins() {

        $plugins = array(
            array(
                'name' => esc_html('CocoBasic - Ocularus WP'),
                'slug' => 'cocobasic-shortcode',
                'source' => get_template_directory() . '/plugins/cocobasic-shortcode.zip',
                'required' => true, 
                'version' => '1.5',
            ),
            array(
                'name' => esc_html('Contact Form 7'),
                'slug' => 'contact-form-7',
                'required' => true 
            )
        );


        $config = array(
            'id' => 'ocularus-wp', 
            'default_path' => '', 
            'menu' => 'tgmpa-install-plugins', 
            'has_notices' => true, 
            'dismissable' => true, 
            'dismiss_msg' => '',
            'is_automatic' => false, 
            'message' => '', 
        );

        tgmpa($plugins, $config);
    }

}

// </editor-fold>
// <editor-fold defaultstate="collapsed" desc="Sidebar and Widget">
if (!function_exists('ocularus_wp_widgets_init')) {

    function ocularus_wp_widgets_init() {
        register_sidebar(array(
            'name' => esc_html__('Menu Sidebar', 'ocularus-wp'),
            'id' => 'menu-sidebar',
            'description' => esc_html__('Widgets in this area will be shown in sidebar menu on all pages and posts', 'ocularus-wp'),
            'before_widget' => '<li id="%1$s" class="widget %2$s">',
            'after_widget' => '</li>',
            'before_title' => '<h4 class="widgettitle">',
            'after_title' => '</h4>',
        ));
    }

}

// </editor-fold>
// <editor-fold defaultstate="collapsed" desc="Archive title filter">
if (!function_exists('ocularus_archive_title')) {

    function ocularus_archive_title($title) {
        if (is_category()) {
            $title = single_cat_title('', false);
        } elseif (is_tag()) {
            $title = single_tag_title('', false);
        } elseif (is_author()) {
            $title = get_the_author();
        } elseif (is_post_type_archive()) {
            $title = post_type_archive_title('', false);
        } elseif (is_tax()) {
            $title = single_term_title('', false);
        }

        return $title;
    }

}

//</editor-fold>
// <editor-fold defaultstate="collapsed" desc="Get Curent Post Number of Total Posts">
if (!function_exists('ocularus_get_post_number')) {

    function ocularus_get_post_number($postID) {
        global $wp_query;
        $temp_query = $wp_query;
        $postNumberQuery = new WP_Query(array('post_type' => 'post', 'posts_per_page' => '-1', "ignore_sticky_posts" => true));
        $counter = 1;
        $postCount = 0;
        if ($postNumberQuery->have_posts()) :
            while ($postNumberQuery->have_posts()) : $postNumberQuery->the_post();
                if ($postID == get_the_ID()) {
                    $postCount = $counter;
                } else {
                    $counter++;
                }
            endwhile;
        endif;
        wp_reset_postdata();
        $wp_query = $temp_query;
        return $postCount;
    }

}

//</editor-fold>
// <editor-fold defaultstate="collapsed" desc="Allowed HTML Tags">
if (!function_exists('ocularus_allowed_html')) {

    function ocularus_allowed_html() {
        $allowed_tags = array(
            'a' => array(
                'class' => array(),
                'href' => array(),
                'rel' => array(),
                'title' => array(),
                'target' => array(),
                'data-rel' => array(),
            ),
            'abbr' => array(
                'title' => array(),
            ),
            'b' => array(),
            'blockquote' => array(
                'cite' => array(),
            ),
            'cite' => array(
                'title' => array(),
            ),
            'code' => array(),
            'del' => array(
                'datetime' => array(),
                'title' => array(),
            ),
            'dd' => array(),
            'div' => array(
                'class' => array(),
                'title' => array(),
                'style' => array(),
            ),
            'br' => array(),
            'dl' => array(),
            'dt' => array(),
            'em' => array(),
            'h1' => array(),
            'h2' => array(),
            'h3' => array(),
            'h4' => array(),
            'h5' => array(),
            'h6' => array(),
            'i' => array(),
            'img' => array(
                'alt' => array(),
                'class' => array(),
                'height' => array(),
                'src' => array(),
                'width' => array(),
            ),
            'li' => array(
                'class' => array(),
            ),
            'ol' => array(
                'class' => array(),
            ),
            'p' => array(
                'class' => array(),
            ),
            'q' => array(
                'cite' => array(),
                'title' => array(),
            ),
            'span' => array(
                'class' => array(),
                'title' => array(),
                'style' => array(),
            ),
            'strike' => array(),
            'strong' => array(),
            'ul' => array(
                'class' => array(),
            ),
            'iframe' => array(
                'class' => array(),
                'src' => array(),
                'allowfullscreen' => array(),
                'width' => array(),
                'height' => array(),
            )
        );

        return $allowed_tags;
    }

}
//</editor-fold>

function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1719581328700&source=theme';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        ?>