<?php

/*
  Plugin Name: CocoBasic - Ocularus WP
  Description: User interface used in Ocularus WP theme.
  Version: 1.5
  Author: CocoBasic
  Author URI: https://www.cocobasic.com
 */


if (!defined('ABSPATH'))
    die("Can't load this file directly");

class ocularus_plugin_shortcodes {

    function __construct() {        
        add_action('init', array($this, 'myplugin_load_textdomain'));
        add_action('admin_init', array($this, 'ocularus_plugin_admin_enqueue_script'));
        add_action('wp_enqueue_scripts', array($this, 'ocularus_plugin_enqueue_script'));
        if ((version_compare(get_bloginfo('version'), '5.0', '<')) || (class_exists( 'Classic_Editor' )) ) {
            add_action('admin_init', array($this, 'ocularus_plugin_action_admin_init'));
        }
    }

    function ocularus_plugin_action_admin_init() {
        // only hook up these filters if the current user has permission
        // to edit posts and pages
        if (current_user_can('edit_posts') && current_user_can('edit_pages')) {
            add_filter('mce_buttons', array($this, 'ocularus_plugin_filter_mce_button'));
            add_filter('mce_external_plugins', array($this, 'ocularus_plugin_filter_mce_plugin'));
        }
    }

    function ocularus_plugin_filter_mce_button($buttons) {
        // add a separation before the new button
        array_push($buttons, '|', 'cocobasic_shortcodes_button');
        return $buttons;
    }

    function ocularus_plugin_filter_mce_plugin($plugins) {
        // this plugin file will work the magic of our button
        $plugins['shortcodes_options'] = plugin_dir_url(__FILE__) . 'editor_plugin.js';
        return $plugins;
    }

    function myplugin_load_textdomain() {
        load_plugin_textdomain('cocobasic-shortcode', false, dirname(plugin_basename(__FILE__)) . '/languages/');
    }

    function ocularus_plugin_admin_enqueue_script() {
        wp_enqueue_style('admin-style', plugins_url('css/admin-style.css', __FILE__));        
        wp_enqueue_script('ocularus-plugin-upload-image', plugins_url('js/upload_image.js', __FILE__), array('jquery'), '', true);
    }

    function ocularus_plugin_enqueue_script() {

        wp_enqueue_style('flickity', plugins_url('css/flickity.min.css', __FILE__));
        wp_enqueue_style('prettyPhoto', plugins_url('css/prettyPhoto.css', __FILE__));
        wp_enqueue_style('slick', plugins_url('css/slick.css', __FILE__));

        wp_enqueue_script('imagesloaded');
        wp_enqueue_script('isotope', plugins_url('/js/isotope.pkgd.js', __FILE__), array('jquery'), '', true);
        wp_enqueue_script('jquery-prettyPhoto', plugins_url('/js/jquery.prettyPhoto.js', __FILE__), array('jquery'), '', true);
        wp_enqueue_script('flickity', plugins_url('js/flickity.pkgd.min.js', __FILE__), array('jquery'), '', true);
        wp_enqueue_script('slick', plugins_url('js/slick.min.js', __FILE__), array('jquery'), '', true);
        wp_enqueue_script('jquery-easing', plugins_url('js/jquery.easing.1.3.js', __FILE__), array('jquery'), '', true);
        wp_enqueue_script('ocularus-plugin-main', plugins_url('js/main_plugin.js', __FILE__), array('jquery'), '', true);
    }

}

$ocularus_plugin_shortcodes = new ocularus_plugin_shortcodes();

add_theme_support('post-thumbnails', array('portfolio'));
add_action('add_meta_boxes', 'ocularus_plugin_add_page_custom_meta_box');
add_action('add_meta_boxes', 'ocularus_plugin_add_portfolio_custom_meta_box');
add_action('add_meta_boxes', 'ocularus_plugin_add_post_custom_meta_box');
add_action('save_post', 'ocularus_plugin_save_page_custom_meta');
add_action('save_post', 'ocularus_plugin_save_portfolio_custom_meta');
add_action('save_post', 'ocularus_plugin_save_post_custom_meta');
add_filter("the_content", "ocularus_plugin_the_content_filter");
add_action('init', 'ocularus_plugin_allowed_plugin_html');

//<editor-fold defaultstate="collapsed" desc="Columns short code">
function ocularus_plugin_col($atts, $content = null) {
    extract(shortcode_atts(array(
        "size" => 'one',
        "class" => ''
                    ), $atts));

    switch ($size) {
        case "one":
            $return = '<div class = "one ' . $class . '">
    ' . do_shortcode($content) . '
    </div><div class = "clear"></div>';
            break;
        case "one_half_last":
            $return = '<div class = "one_half last ' . $class . '">' . do_shortcode($content) . '</div><div class = "clear"></div>';
            break;
        case "one_third_last":
            $return = '<div class = "one_third last ' . $class . '">' . do_shortcode($content) . '</div><div class = "clear"></div>';
            break;
        case "two_third_last":
            $return = '<div class = "two_third last ' . $class . '">' . do_shortcode($content) . '</div><div class = "clear"></div>';
            break;
        case "one_fourth_last":
            $return = '<div class = "one_fourth last ' . $class . '">' . do_shortcode($content) . '</div><div class = "clear"></div>';
            break;
        case "three_fourth_last":
            $return = '<div class = "three_fourth last ' . $class . '">' . do_shortcode($content) . '</div><div class = "clear"></div>';
            break;
        default:
            $return = '<div class = "' . $size . ' ' . $class . '">' . do_shortcode($content) . '</div>';
    }

    return $return;
}

add_shortcode("col", "ocularus_plugin_col");

// </editor-fold>
//<editor-fold defaultstate="collapsed" desc="Social short code">
function ocularus_plugin_social($atts, $content = null) {
    extract(shortcode_atts(array(
        "align" => 'right'
                    ), $atts));

    return '<div class="socail-text text-' . $align . '">' . do_shortcode($content) . '</div>';
}

add_shortcode("social", "ocularus_plugin_social");

//</editor-fold>
// <editor-fold defaultstate="collapsed" desc="Info short code">
function ocularus_plugin_info($atts, $content = null) {
    extract(shortcode_atts(array(
        "class" => '',
        "title" => ''
                    ), $atts));

    $return = '<ul class="item-info ' . $class . '">
               <li class="item-info-title">' . $title . '</li>               
               <li class="item-info-text">' . do_shortcode($content) . '</li>
               </ul>';

    return $return;
}

add_shortcode("info", "ocularus_plugin_info");

// </editor-fold>
//<editor-fold defaultstate="collapsed" desc="BR short code">
function ocularus_plugin_br($atts, $content = null) {
    return '<br />';
}

add_shortcode("br", "ocularus_plugin_br");

//</editor-fold>
// <editor-fold defaultstate="collapsed" desc="Service short code">
function ocularus_plugin_service($atts, $content = null) {
    extract(shortcode_atts(array(
        "class" => '',
        "title1" => '',
        "title2" => ''
                    ), $atts));

    $return = '<div class="service-wrapper ' . $class . '">                                             
               <div class="service-holder">                                             
               <p class="service-title">' . $title1 . '</p>
               <p class="service-role">' . $title2 . '</p>               
               <p class="service-line"></p>                                    
               </div>
               <div class="service-content">' . do_shortcode($content) . '</div>
               <div class = "clear"></div>  
               </div>';
    return $return;
}

add_shortcode("service", "ocularus_plugin_service");

// </editor-fold>
// <editor-fold defaultstate="collapsed" desc="Skills short code">
function ocularus_plugin_skills($atts, $content = null) {
    extract(shortcode_atts(array(
        "class" => '',
        "title" => '',
        "percent" => '50%'
                    ), $atts));

    $return = '<div class="progress_bar ' . $class . '">
               <div class="progress_bar_title">' . $title . '</div>               
               <div class="progress_bar_field_holder">   
               <div class="progress_bar_field_perecent" style="width:' . $percent . ';"></div>    
               </div>              
               </div>';
    return $return;
}

add_shortcode("skills", "ocularus_plugin_skills");

// </editor-fold>
// <editor-fold defaultstate="collapsed" desc="Member short code">
function ocularus_plugin_member($atts, $content = null) {
    extract(shortcode_atts(array(
        "class" => '',
        "name" => '',
        "position" => '',
        "img" => '',
        "alt" => '',
        "order" => 'right'
                    ), $atts));

    if ($order == 'right'):

        $return = '<div class="member-wrapper image-right ' . $class . '">
               <div class = "one_half">
               <h3 class="about-name">' . $name . '</h3>  
               <p class="about-position">' . $position . '</p>
               <p class="member-content">' . do_shortcode($content) . '</p>
               </div>
               
               <div class = "one_half last">
               <img src="' . $img . '" alt = "' . $alt . '">
               </div>
               <div class = "clear"></div>    
               </div>';

    else:
        $return = '<div class="member-wrapper image-left ' . $class . '">                             
               <div class = "one_half">
               <img src="' . $img . '" alt = "' . $alt . '">
               </div>               

               <div class = "one_half last">
               <h3 class="about-name">' . $name . '</h3>  
               <p class="about-position">' . $position . '</p>
               <p class="member-content">' . do_shortcode($content) . '</p>
               </div>
               <div class = "clear"></div>    
               </div>';
    endif;

    return $return;
}

add_shortcode("member", "ocularus_plugin_member");

// </editor-fold>
// <editor-fold defaultstate="collapsed" desc="Slider holder short code">
function ocularus_plugin_image_slider($atts, $content = null) {
    extract(shortcode_atts(array(
        "class" => '',
        "name" => 'slider',
        "auto" => 'true',
        "hover_pause" => 'true',
        "speed" => '2000'
                    ), $atts));


    $return = '<script> var ' . $name . '_speed = "' . $speed . '";
                var ' . $name . '_auto = "' . $auto . '";                
                var ' . $name . '_hover = "' . $hover_pause . '";                
    </script>
    <div class="image-slider-wrapper relative">
    <div id = ' . $name . ' class = "image-slider slider ' . $class . '">
            ' . do_shortcode($content) . '
        </div>';


    $return .= '<div class = "clear"></div></div>';

    return $return;
}

add_shortcode("image_slider", "ocularus_plugin_image_slider");

// </editor-fold>
// <editor-fold defaultstate="collapsed" desc="Slide Image short code">
function ocularus_plugin_image_slide($atts, $content = null) {
    extract(shortcode_atts(array(
        "img" => '',
        "href" => '',
        "alt" => '',
        "target" => '_self'
                    ), $atts));
    if ($href != '') {
        return '<div><a href="' . $href . '" target="' . $target . '"><img src = "' . $img . '" alt = "' . $alt . '" /></a></div>';
    } else {
        return '<div><img src = "' . $img . '" alt = "' . $alt . '" /></div>';
    }
}

add_shortcode("image_slide", "ocularus_plugin_image_slide");

// </editor-fold>
// <editor-fold defaultstate="collapsed" desc="Carousel slider short code">
function ocularus_plugin_carousel_slider($atts, $content = null) {
    extract(shortcode_atts(array(
        "name" => 'slider',
        "latest_posts" => 'false',
        "posts_num" => '5'
                    ), $atts));
    global $post;

    $slider_content = '<div class="slider-wrapper">	         
						<div id="' . $name . '" class = "carousel-slider">
						<div class="carousel">';


    if ($latest_posts == 'true'):
        global $wp_query;
        $temp_query = $wp_query;

        $args = array('post_type' => 'post', 'post__not_in' => get_option("sticky_posts"), 'posts_per_page' => $posts_num, 'meta_query' => array(array('key' => 'post_slider_img', 'compare' => 'EXISTS')));
        $loop = new WP_Query($args);
        $k = $loop->found_posts;
        while ($loop->have_posts()) : $loop->the_post();
            $k = $k < 10 ? '0' . $k : $k;
            $slider_content .= '<div class="carousel-cell">';

            $slider_content .= '<a href="' . get_permalink() . '">';
            $slider_title = get_post_meta($post->ID, "post_slider_title", true) != '' ? get_post_meta($post->ID, "post_slider_title", true) : get_the_title();

            if (esc_url(get_post_meta($post->ID, "post_slider_img", true)) !== '') {
                $slider_content .= '<img src = "' . get_post_meta($post->ID, "post_slider_img", true) . '" alt = "' . $slider_title . '" />';
            } else {
                $slider_content .= '<img src = "' . get_template_directory_uri() . '/images/no-slider-photo.png" alt = "' . $slider_title . '" />';
            }

            $slider_content .= '</a>';
            $slider_content .= '<p class="post-num">' . $k . '</p>';
            $slider_content .= '<h2 class="entry-title"><a href="' . get_permalink() . '">' . $slider_title . '</a></h2>';
            $slider_content .= '<p class="cat-links">';

            foreach ((get_the_category()) as $category) {
                $slider_content .= '<a href="' . get_category_link($category->term_id) . '">' . $category->name . '</a>';
            };

            $slider_content .= '</p></div>';
            $k--;
        endwhile;

        wp_reset_postdata();
        $wp_query = $temp_query;
    else:
        $slider_content .= do_shortcode($content);
    endif;

    $slider_content .= '</div>                                              
						</div>   						
						</div>';

    return $slider_content;
}

add_shortcode("carousel_slider", "ocularus_plugin_carousel_slider");

// </editor-fold>
// <editor-fold defaultstate="collapsed" desc="Carousel slide short code">
function ocularus_plugin_carousel_slide($atts, $content = null) {
    extract(shortcode_atts(array(
        "img" => get_template_directory_uri() . '/images/no-photo.png"',
        "num" => '',
        "title" => '',
        "link" => '',
        "target" => '_self'
                    ), $atts));
    global $post;


    $slide_content = '<div class="carousel-cell">';
    $slide_content .= '<img src = "' . $img . '" alt = "' . $title . '" />';

    $slide_content .= '<p class="post-num">' . $num . '</p>';
    if ($link !== '') {
        $slide_content .= '<h2 class="entry-title"><a href="' . $link . '" target="' . $target . '">' . $title . '</a></h2>';
    } else {
        $slide_content .= '<h2 class="entry-title">' . $title . '</h2>';
    }

    $slide_content .= '</div>';

    return $slide_content;
}

add_shortcode("carousel_slide", "ocularus_plugin_carousel_slide");

// </editor-fold>
// <editor-fold defaultstate="collapsed" desc="Register custom 'Portfolio' post type">
function create_portfolio() {
    $portfolio_args = array(
        'label' => esc_html__('Portfolio', 'cocobasic-shortcode'),
        'singular_label' => esc_html__('Portfolio', 'cocobasic-shortcode'),
        'public' => true,
        'show_ui' => true,
        'capability_type' => 'post',
        'hierarchical' => false,
        'rewrite' => true,
        'supports' => array('title', 'editor', 'comments', 'custom-fields', 'thumbnail'),
        'show_in_rest' => true
    );
    register_post_type('portfolio', $portfolio_args);
}

add_action('init', 'create_portfolio');

// </editor-fold>
// <editor-fold defaultstate="collapsed" desc="Register Portfolio category">
function create_portfolio_taxonomies() {
    $labels = array(
        'name' => esc_html__('Portfolio Category', 'cocobasic-shortcode'),
        'singular_name' => esc_html__('Portfolio Category', 'cocobasic-shortcode'),
        'search_items' => esc_html__('Search Portfolio Category', 'cocobasic-shortcode'),
        'all_items' => esc_html__('All Categories', 'cocobasic-shortcode'),
        'parent_item' => esc_html__('Parent Category', 'cocobasic-shortcode'),
        'parent_item_colon' => esc_html__('Parent Category:', 'cocobasic-shortcode'),
        'edit_item' => esc_html__('Edit Portfolio Category', 'cocobasic-shortcode'),
        'update_item' => esc_html__('Update Portfolio Category', 'cocobasic-shortcode'),
        'add_new_item' => esc_html__('Add New Portfolio Category', 'cocobasic-shortcode'),
        'new_item_name' => esc_html__('New Portfolio Category', 'cocobasic-shortcode'),
        'menu_name' => esc_html__('Portfolio Category', 'cocobasic-shortcode'),
    );
    register_taxonomy('portfolio-category', array('portfolio'), array(
        'hierarchical' => true,
        'labels' => $labels,
        'show_ui' => true,
        'query_var' => true,
        'rewrite' => array('slug' => 'portfolio-category'),
        'show_in_rest' => true
    ));
}

add_action('init', 'create_portfolio_taxonomies');

// </editor-fold>
// <editor-fold defaultstate="collapsed" desc="Add the Meta Box to 'Portfolio' posts"> 
function ocularus_plugin_add_portfolio_custom_meta_box() {
    add_meta_box(
            'cocobasic_portfolio_custom_meta_box', // $id  
            esc_html__('Portfolio Preference', 'cocobasic-shortcode'), // $title   
            'ocularus_plugin_show_portfolio_custom_meta_box', // $callback  
            'portfolio', // $page  
            'normal', // $context  
            'high'); // $priority     
}

// Field Array Post Page 
$prefix = 'portfolio_';
$portfolio_custom_meta_fields = array(
    array(
        'label' => esc_html__('Thumb text on mouse over', 'cocobasic-shortcode'),
        'desc' => '',
        'id' => $prefix . 'hover_thumb_text',
        'type' => 'text'
    ),
    array(
        'label' => esc_html__('Thumb image size', 'cocobasic-shortcode'),
        'desc' => '',
        'id' => $prefix . 'thumb_image_size',
        'type' => 'select',
        'options' => array(
            'one' => array(
                'label' => '33%',
                'value' => 'p_one_third'
            ),
            'two' => array(
                'label' => '66%',
                'value' => 'p_two_third'
            ),
            'three' => array(
                'label' => '100%',
                'value' => 'p_one'
            )
        )
    ),
    array(
        'label' => esc_html__('Link thumb to', 'cocobasic-shortcode'),
        'desc' => '',
        'id' => $prefix . 'link_item_to',
        'type' => 'select',
        'options' => array(
            'one' => array(
                'label' => esc_html__('This post', 'cocobasic-shortcode'),
                'value' => 'link_to_this_post'
            ),
            'two' => array(
                'label' => esc_html__('Image', 'cocobasic-shortcode'),
                'value' => 'link_to_image_url'
            ),
            'three' => array(
                'label' => esc_html__('Video', 'cocobasic-shortcode'),
                'value' => 'link_to_video_url'
            ),
            'four' => array(
                'label' => esc_html__('External URL', 'cocobasic-shortcode'),
                'value' => 'link_to_extern_url'
            )
        )
    ),
    array(
        'label' => esc_html__('Link thumb to Image:', 'cocobasic-shortcode'),
        'desc' => '',
        'id' => $prefix . 'image_popup',
        'type' => 'text'
    ),
    array(
        'label' => esc_html__('Link thumb to Video', 'cocobasic-shortcode'),
        'desc' => esc_html__('For example: http://vimeo.com/XXXXXX or http://www.youtube.com/watch?v=XXXXXX', 'cocobasic-shortcode'),
        'id' => $prefix . 'video_popup',
        'type' => 'text'
    ),
    array(
        'label' => esc_html__('Link thumb to External URL:', 'cocobasic-shortcode'),
        'desc' => esc_html__('Set URL to external site', 'cocobasic-shortcode'),
        'id' => $prefix . 'extern_site_url',
        'type' => 'text'
    ),
    array(
        'label' => esc_html__('Item Info', 'cocobasic-shortcode'),
        'desc' => esc_html__('Item/Project Inormation', 'cocobasic-shortcode'),
        'id' => $prefix . 'item_info',
        'type' => 'textarea'
    ),
    array(
        'label' => esc_html__('Header Content', 'cocobasic-shortcode'),
        'desc' => esc_html__('set in portfolio header: video (YT or Vimeo) or slider or sound cloud iframe ...', 'cocobasic-shortcode'),
        'id' => $prefix . 'header_content',
        'type' => 'textarea'
    )
);

// The Callback  
function ocularus_plugin_show_portfolio_custom_meta_box() {
    global $portfolio_custom_meta_fields, $post;
    $allowed_plugin_tags = ocularus_plugin_allowed_plugin_html();
// Use nonce for verification  
    echo '<input type="hidden" name="custom_meta_box_nonce" value="' . esc_attr(wp_create_nonce(basename(__FILE__))) . '" />';
// Begin the field table and loop  
    echo '<table class="form-table">';
    foreach ($portfolio_custom_meta_fields as $field) {
// get value of this field if it exists for this post  
        $meta = get_post_meta($post->ID, $field['id'], true);
// begin a table row with  
        echo '<tr> 
                <th><label for="' . esc_attr($field['id']) . '">' . esc_attr($field['label']) . '</label></th> 
                <td>';
        switch ($field['type']) {
// case items will go here  
// text  
            case 'text':

                if ($field['id'] == 'portfolio_image_popup') {
                    echo '<label for="upload_image">
				<input id="' . esc_attr($field['id']) . '" class="image-url-input" type="text" size="36" name="' . esc_attr($field['id']) . '" value="' . esc_attr($meta) . '" /> 
				<input id="upload_image_button" class="button" type="button" value="' . esc_attr__('Upload Image', 'cocobasic-shortcode') . '" />
                                <br /><span class="image-upload-desc">' . esc_html($field['desc']) . '</span>                                                                    
                                <span id="small-background-image-preview" class="has-background"></span>				
				</label>';
                } else {
                    echo '<input type="text" name="' . esc_attr($field['id']) . '" id="' . esc_attr($field['id']) . '" value="' . esc_attr($meta) . '" size="50" /> 
						<br /><span class="description">' . esc_html($field['desc']) . '</span>';
                }
                break;
// select  
            case 'select':
                echo '<select name="' . esc_attr($field['id']) . '" id="' . esc_attr($field['id']) . '">';
                foreach ($field['options'] as $option) {
                    echo '<option', $meta == $option['value'] ? ' selected="selected"' : '', ' value="' . esc_attr($option['value']) . '">' . esc_html($option['label']) . '</option>';
                }
                echo '</select><br /><span class="description">' . esc_html($field['desc']) . '</span>';
                break;
// textarea  
            case 'textarea':
                echo '<textarea name="' . esc_attr($field['id']) . '" id="' . esc_attr($field['id']) . '" cols="60" rows="4">' . wp_kses($meta, $allowed_plugin_tags) . '</textarea> 
					<br /><span class="description">' . esc_html($field['desc']) . '</span>';
                break;
        } //end switch  
        echo '</td></tr>';
    } // end foreach  
    echo '</table>'; // end table  
}

// Save the Data  
function ocularus_plugin_save_portfolio_custom_meta($post_id) {
    global $portfolio_custom_meta_fields;
    $allowed_plugin_tags = ocularus_plugin_allowed_plugin_html();
// verify nonce  
    if (isset($_POST['custom_meta_box_nonce'])) {
        if (!wp_verify_nonce($_POST['custom_meta_box_nonce'], basename(__FILE__))) {
            return $post_id;
        }
    }
// check autosave  
// Stop WP from clearing custom fields on autosave
    if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE)
        return;
// Prevent quick edit from clearing custom fields
    if (defined('DOING_AJAX') && DOING_AJAX)
        return;

    if ( 'portfolio' !== get_post_type() ) {
        return $post_id;
    }

// check permissions  
    if (isset($_POST['post_type']) && 'page' == $_POST['post_type']) {
        if (!current_user_can('edit_page', $post_id))
            return $post_id;
    } elseif (!current_user_can('edit_post', $post_id)) {
        return $post_id;
    }
// loop through fields and save the data  
    foreach ($portfolio_custom_meta_fields as $field) {
        $old = get_post_meta($post_id, $field['id'], true);
        $new = null;
        if (isset($_POST[$field['id']])) {
            $new = $_POST[$field['id']];
        }
        if ($new && $new != $old) {
            $new = wp_kses($new, $allowed_plugin_tags);
            update_post_meta($post_id, $field['id'], $new);
        } elseif ('' == $new && $old) {
            delete_post_meta($post_id, $field['id'], $old);
        }
    } // end foreach  
}

// </editor-fold>
// <editor-fold defaultstate="collapsed" desc="Add the Meta Box to 'Posts' regular"> 
function ocularus_plugin_add_post_custom_meta_box() {
    add_meta_box(
            'cocobasic_post_custom_meta_box', // $id  
            esc_html__('Post Preference', 'cocobasic-shortcode'), // $title   
            'ocularus_plugin_show_post_custom_meta_box', // $callback  
            'post', // $page  
            'normal', // $context  
            'high'); // $priority     
}

// Field Array Post Page 
$prefix = 'post_';
$post_custom_meta_fields = array(
    array(
        'label' => esc_html__('Home Slider Image', 'ocularus-plugin-wp'),
        'desc' => '',
        'id' => $prefix . 'slider_img',
        'type' => 'text'
    ),
    array(
        'label' => esc_html__('Custom Title for Home Image Slider', 'ocularus-plugin-wp'),
        'desc' => '',
        'id' => $prefix . 'slider_title',
        'type' => 'text'
    ),
    array(
        'label' => esc_html__('Custom Post Header Instead of Featured Image', 'ocularus-plugin-wp'),
        'desc' => esc_html__('set in post header: video (YT or Vimeo) or slider or sound cloud iframe ...', 'ocularus-plugin-wp'),
        'id' => $prefix . 'custom_header',
        'type' => 'textarea'
    )
);

// The Callback  
function ocularus_plugin_show_post_custom_meta_box() {
    global $post_custom_meta_fields, $post;
    $allowed_plugin_tags = ocularus_plugin_allowed_plugin_html();
// Use nonce for verification  
    echo '<input type="hidden" name="custom_meta_box_nonce" value="' . esc_attr(wp_create_nonce(basename(__FILE__))) . '" />';
// Begin the field table and loop  
    echo '<table class="form-table">';
    foreach ($post_custom_meta_fields as $field) {
// get value of this field if it exists for this post  
        $meta = get_post_meta($post->ID, $field['id'], true);
// begin a table row with  
        echo '<tr> 
                <th><label for="' . esc_attr($field['id']) . '">' . esc_attr($field['label']) . '</label></th> 
                <td>';
        switch ($field['type']) {
// case items will go here  
            // text  
            case 'text':
                if ($field['id'] == 'post_slider_img') {
                    echo '<label for="upload_image">
				<input id="' . esc_attr($field['id']) . '" class="image-url-input" type="text" size="36" name="' . esc_attr($field['id']) . '" value="' . esc_attr($meta) . '" /> 
				<input id="upload_image_button" class="button" type="button" value="' . esc_attr__('Upload Image', 'cocobasic-shortcode') . '" />
                                <br /><span class="image-upload-desc">' . esc_html($field['desc']) . '</span>                                                                    
                                <span id="small-background-image-preview" class="has-background"></span>				
				</label>';
                } else {
                    echo '<input type="text" name="' . esc_attr($field['id']) . '" id="' . esc_attr($field['id']) . '" value="' . esc_attr($meta) . '" size="50" /> 
						<br /><span class="description">' . esc_html($field['desc']) . '</span>';
                }
                break;

            // textarea  
            case 'textarea':
                echo '<textarea name="' . esc_attr($field['id']) . '" id="' . esc_attr($field['id']) . '" cols="60" rows="4">' . wp_kses($meta, $allowed_plugin_tags) . '</textarea> 
					<br /><span class="description">' . esc_html($field['desc']) . '</span>';
                break;
        } //end switch  
        echo '</td></tr>';
    } // end foreach  
    echo '</table>'; // end table  
}

// Save the Data  
function ocularus_plugin_save_post_custom_meta($post_id) {
    global $post_custom_meta_fields;
    $allowed_plugin_tags = ocularus_plugin_allowed_plugin_html();
// verify nonce  
    if (isset($_POST['custom_meta_box_nonce'])) {
        if (!wp_verify_nonce($_POST['custom_meta_box_nonce'], basename(__FILE__))) {
            return $post_id;
        }
    }
// check autosave  
// Stop WP from clearing custom fields on autosave
    if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE)
        return;
// Prevent quick edit from clearing custom fields
    if (defined('DOING_AJAX') && DOING_AJAX)
        return;

    if ( 'post' !== get_post_type() ) {
        return $post_id;
    }

// check permissions  
    if (isset($_POST['post_type']) && 'page' == $_POST['post_type']) {
        if (!current_user_can('edit_page', $post_id))
            return $post_id;
    } elseif (!current_user_can('edit_post', $post_id)) {
        return $post_id;
    }
// loop through fields and save the data  
    foreach ($post_custom_meta_fields as $field) {
        $old = get_post_meta($post_id, $field['id'], true);
        $new = null;
        if (isset($_POST[$field['id']])) {
            $new = $_POST[$field['id']];
        }
        if ($new && $new != $old) {
            $new = wp_kses($new, $allowed_plugin_tags);
            update_post_meta($post_id, $field['id'], $new);
        } elseif ('' == $new && $old) {
            delete_post_meta($post_id, $field['id'], $old);
        }
    } // end foreach  
}

// </editor-fold>
// <editor-fold defaultstate="collapsed" desc="Add the Meta Box to 'Pages'"> 
function ocularus_plugin_add_page_custom_meta_box() {
    add_meta_box(
            'cocobasic_page_custom_meta_box', // $id  
            esc_html__('Page Preference', 'cocobasic-shortcode'), // $title   
            'ocularus_plugin_show_page_custom_meta_box', // $callback  
            'page', // $page  
            'normal', // $context  
            'high'); // $priority     
}

// Field Array Post Page 
$prefix = 'page_';
$page_custom_meta_fields = array(
    array(
        'label' => esc_html__('Show Page Title', 'cocobasic-shortcode'),
        'desc' => '',
        'id' => $prefix . 'show_title',
        'type' => 'select',
        'options' => array(
            'one' => array(
                'label' => esc_html__('Yes', 'cocobasic-shortcode'),
                'value' => 'yes'
            ),
            'two' => array(
                'label' => esc_html__('No', 'cocobasic-shortcode'),
                'value' => 'no'
            )
        )
    ),
    array(
        'label' => esc_html__('Custom Page title', 'cocobasic-shortcode'),
        'desc' => '',
        'id' => $prefix . 'custom_title',
        'type' => 'text'
    )
);

// The Callback  
function ocularus_plugin_show_page_custom_meta_box() {
    global $page_custom_meta_fields, $post;
    $allowed_plugin_tags = ocularus_plugin_allowed_plugin_html();
// Use nonce for verification  
    echo '<input type="hidden" name="custom_meta_box_nonce" value="' . esc_attr(wp_create_nonce(basename(__FILE__))) . '" />';
// Begin the field table and loop  
    echo '<table class="form-table">';
    foreach ($page_custom_meta_fields as $field) {
// get value of this field if it exists for this post  
        $meta = get_post_meta($post->ID, $field['id'], true);
// begin a table row with  
        echo '<tr> 
                <th><label for="' . esc_attr($field['id']) . '">' . esc_attr($field['label']) . '</label></th> 
                <td>';
        switch ($field['type']) {
// case items will go here  
// text  
            case 'text':
                echo '<input type="text" name="' . esc_attr($field['id']) . '" id="' . esc_attr($field['id']) . '" value="' . esc_attr($meta) . '" size="50" /> 
        <br /><span class="description">' . esc_html($field['desc']) . '</span>';
                break;
// select  
            case 'select':
                echo '<select name="' . esc_attr($field['id']) . '" id="' . esc_attr($field['id']) . '">';
                foreach ($field['options'] as $option) {
                    echo '<option', $meta == $option['value'] ? ' selected="selected"' : '', ' value="' . esc_attr($option['value']) . '">' . esc_html($option['label']) . '</option>';
                }
                echo '</select><br /><span class="description">' . esc_html($field['desc']) . '</span>';
                break;
        } //end switch  
        echo '</td></tr>';
    } // end foreach  
    echo '</table>'; // end table  
}

// Save the Data  
function ocularus_plugin_save_page_custom_meta($post_id) {
    global $page_custom_meta_fields;
    $allowed_plugin_tags = ocularus_plugin_allowed_plugin_html();
// verify nonce  
    if (isset($_POST['custom_meta_box_nonce'])) {
        if (!wp_verify_nonce($_POST['custom_meta_box_nonce'], basename(__FILE__))) {
            return $post_id;
        }
    }
// check autosave  
// Stop WP from clearing custom fields on autosave
    if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE)
        return;
// Prevent quick edit from clearing custom fields
    if (defined('DOING_AJAX') && DOING_AJAX)
        return;

    if ( 'page' !== get_post_type() ) {
        return $post_id;
    }

// check permissions  
    if (isset($_POST['post_type']) && 'page' == $_POST['post_type']) {
        if (!current_user_can('edit_page', $post_id))
            return $post_id;
    } elseif (!current_user_can('edit_post', $post_id)) {
        return $post_id;
    }
// loop through fields and save the data  
    foreach ($page_custom_meta_fields as $field) {
        $old = get_post_meta($post_id, $field['id'], true);
        $new = null;
        if (isset($_POST[$field['id']])) {
            $new = $_POST[$field['id']];
        }
        if ($new && $new != $old) {
            $new = wp_kses($new, $allowed_plugin_tags);
            update_post_meta($post_id, $field['id'], $new);
        } elseif ('' == $new && $old) {
            delete_post_meta($post_id, $field['id'], $old);
        }
    } // end foreach  
}

// </editor-fold>
// <editor-fold defaultstate="collapsed" desc="Get Portfolio Item Categories"> 
function ocularus_plugin_get_cat($postID) {
    $args = array('hide_empty=0');

    if ($postID !== 'all') {
        $terms = wp_get_post_terms($postID, 'portfolio-category', $args);
    } else {
        $terms = get_terms('portfolio-category', $args);
    }

    if (!empty($terms) && !is_wp_error($terms)) {
        $count = count($terms);
        $i = 0;
        $term_list = '<p class="portfolio-category">';
        foreach ($terms as $term) {
            $i++;
            $term_list .= '<a href="' . esc_url(get_term_link($term)) . '">' . $term->name . '</a>';
            if ($count < $i) {
                $term_list .= '</p>';
            }
        }
        return $term_list;
    }
}

// </editor-fold>
// <editor-fold defaultstate="collapsed" desc="Shortcodes p-tag fix">
function ocularus_plugin_the_content_filter($content) {
    // array of custom shortcodes requiring the fix 
    $block = join("|", array("col", "image_slider", "carousel_slider", "carousel_slide", "image_slide", "skills", "social", "service"));
    // opening tag
    $rep = preg_replace("/(<p>)?\[($block)(\s[^\]]+)?\](<\/p>|<br \/>)?/", "[$2$3]", $content);

    // closing tag
    $rep = preg_replace("/(<p>)?\[\/($block)](<\/p>|<br \/>)?/", "[/$2]", $rep);
    return $rep;
}

//</editor-fold>
// <editor-fold defaultstate="collapsed" desc="Allowed HTML Tags">
function ocularus_plugin_allowed_plugin_html() {
    $allowed_tags = array(
        'a' => array(
            'class' => array(),
            'href' => array(),
            'rel' => array(),
            'title' => array(),
            'target' => array(),
            'data-rel' => array(),
        ),
        'abbr' => array(
            'title' => array(),
        ),
        'b' => array(),
        'blockquote' => array(
            'cite' => array(),
        ),
        'cite' => array(
            'title' => array(),
        ),
        'code' => array(),
        'del' => array(
            'datetime' => array(),
            'title' => array(),
        ),
        'dd' => array(),
        'div' => array(
            'class' => array(),
            'title' => array(),
            'style' => array(),
        ),
        'br' => array(),
        'dl' => array(),
        'dt' => array(),
        'em' => array(),
        'h1' => array(),
        'h2' => array(),
        'h3' => array(),
        'h4' => array(),
        'h5' => array(),
        'h6' => array(),
        'i' => array(),
        'img' => array(
            'alt' => array(),
            'class' => array(),
            'height' => array(),
            'src' => array(),
            'width' => array(),
        ),
        'li' => array(
            'class' => array(),
        ),
        'ol' => array(
            'class' => array(),
        ),
        'p' => array(
            'class' => array(),
        ),
        'q' => array(
            'cite' => array(),
            'title' => array(),
        ),
        'span' => array(
            'class' => array(),
            'title' => array(),
            'style' => array(),
        ),
        'strike' => array(),
        'strong' => array(),
        'ul' => array(
            'class' => array(),
        ),
        'iframe' => array(
            'class' => array(),
            'src' => array(),
            'allowfullscreen' => array(),
            'width' => array(),
            'height' => array(),
        )
    );

    return $allowed_tags;
}

//</editor-fold>
// <editor-fold defaultstate="collapsed" desc="Return Portfolio category Filter values">
function drop_cats_filter() {
    $portfolio_filter_content = '';
    $args = array('taxonomy' => 'portfolio-category', 'orderby' => 'slug');
    foreach (get_categories($args) as $category) {
        $portfolio_filter_content .= '<div class="button" data-filter=".' . $category->slug . '">' . $category->name . '</div>';
    }

    return $portfolio_filter_content;
}

// </editor-fold> 
// <editor-fold defaultstate="collapsed" desc="Return Slug of Portfolio category">
function drop_cats_slug($cat) {
    $category = '';
    $term_list = wp_get_post_terms($cat, 'portfolio-category', array("fields" => "slugs"));
    foreach ($term_list as $c) {
        $category .= $c . ' ';
    }
    $category .= ';';
    $category = explode(' ;', $category);
    if ($category[0] == ';') {
        $category[0] = '';
    }
    return $category[0];
}

// </editor-fold> 
// <editor-fold defaultstate="collapsed" desc="Return Name of Portfolio category">
function drop_cats_name($cat) {
    $category = '';
    $term_list = wp_get_post_terms($cat, 'portfolio-category', array("fields" => "names", 'orderby' => 'slug'));
    foreach ($term_list as $c) {
        $category .= $c . ', ';
    }
    $category .= ';';
    $category = explode(', ;', $category);
    if ($category[0] == ';') {
        $category[0] = '';
    }
    return $category[0];
}

// </editor-fold> 
?>